# save-session
# 2015-03-20


# initial settings
pluginDir$ = preferencesDirectory$ + "/plugin_PraatSessions"
sessionsDirPref$ = pluginDir$ + "/sessionsDir"
@splitDate
sessionNameDefault$ = splitDate.year$ + "-" + splitDate.month$ + "-" +  splitDate.day$ + "_" +  splitDate.time$


# test for available objects
select all
nSelected = numberOfSelected ()
if nSelected = 0
	beginPause: "Save session (no objects)"
		comment: "You don't have any objects in the objects list."
		comment: "Create some objects and try again."
	endPause: "OK", 1, 1
	exitScript: ()
endif


# look for default directory
if fileReadable (sessionsDirPref$)
	sessionsDir$ = readFile$ (sessionsDirPref$)
	# ensure that the default directory exists
	createDirectory: sessionsDir$
else
	# set new default directory
	beginPause: "Save session (first run)"
		comment: "Your default directory for Praat sessions is not yet set."
		comment: "Please choose a directory where all Praat sessions will be saved."
	clicked = endPause: "Cancel", "OK", 2, 1
	if clicked = 1
		exitScript ()
	elsif clicked = 2
		sessionsDir$ = chooseDirectory$: "Choose a directory for Praat sessions"
		if sessionsDir$ <> ""
			createDirectory: sessionsDir$
			writeFile: sessionsDirPref$, sessionsDir$
		else
			exitScript ()
		endif
	endif
endif


# save-as-form
beginPause: "Save session"
	sentence: "Save session as", sessionNameDefault$
	comment: ""
	comment: "Your default directory to manage Praat sessions is:"
	comment: "          " + sessionsDir$
	comment: "To change the default directory select [Set sessions directory...]"
	comment: "from the Praat menu."
	clicked = endPause: "Cancel", "Save", 2, 1
if clicked = 1
	exitScript ()
endif


# react to existing session
sessionName$ = save_session_as$ + ".collection"
if fileReadable (sessionsDir$ + "/" + sessionName$)
	beginPause: "Save session"
		comment: "Save session as: " + save_session_as$
		comment: "A session with that name already exists."
		comment: "Do you want to append the current objects to the existing session"
		comment: "or do you want to replace (=delete) the existing session? If you"
		comment: "want neither, cancel and start over."
	clicked = endPause: "Cancel", "Replace", "Append", 3, 1
	if clicked = 1
		exitScript ()
	elsif clicked = 2
		deleteFile: sessionsDir$ + "/" + sessionName$
	elsif clicked = 3
		Read from file: sessionsDir$ + "/" + sessionName$
		nAppended = numberOfSelected ()
		for i to nAppended
			appended [i] = selected ()
		endfor
	endif
endif
	

# save objects as Praat collection
select all
nSelected = numberOfSelected ()
Save as binary file: sessionsDir$ + "/" + sessionName$
for i to nAppended
	removeObject: appended [i]
endfor


beginPause: "Finished"
	comment: string$ (nSelected) + " objects where saved to " + sessionName$
endPause: "OK", 1, 1



procedure splitDate
	.date$ = date$ ()
	.year$ = right$ (.date$, 4)
	.month$ = mid$ (.date$, 5, 3)
	if .month$ = "Jan"
		.month$ = "01"
	elsif .month$ = "Feb"
		.month$ = "02"
	elsif .month$ = "Mar"
		.month$ = "03"
	elsif .month$ = "Apr"
		.month$ = "04"
	elsif .month$ = "May"
		.month$ = "05"
	elsif .month$ = "Jun"
		.month$ = "06"
	elsif .month$ = "Jul"
		.month$ = "07"
	elsif .month$ = "Aug"
		.month$ = "08"
	elsif .month$ = "Sep"
		.month$ = "09"
	elsif .month$ = "Oct"
		.month$ = "10"
	elsif .month$ = "Nov"
		.month$ = "11"
	elsif .month$ = "Dec"
		.month$ = "12"
	endif
	.day$ = mid$ (.date$, 9, 2)
	.day$ = replace$ (.day$, " ", "0", 0)
	.time$ = mid$ (.date$, 12, 8)
	.time$ = replace$ (.time$, ":", "-", 0)
endproc


